==> zio-aws-macie2_2.13-5.17.295.9-sources.jar: zio/aws/macie2/model/package.scala <==
package zio.aws.macie2
import zio.prelude.Subtype
import zio.aws.macie2.model.primitives.__string
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.macie2.model.primitives.MaxResults.Type
    type __boolean = Boolean
    type __double = Double
    type __integer = Int
    type __long = Long
    type __string = String
    type __stringMin1Max1024PatternSS = String
    type __stringMin1Max128 = String
    type __stringMin1Max128Pattern = String
    type __stringMin1Max2048 = String
    type __stringMin1Max512PatternSS = String
    type __stringMin22Max22PatternAZ0922 = String
    type __stringMin3Max255PatternAZaZ093255 = String
    type __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922 =
      String
    type __timestampIso8601 = Instant
  }
  type BucketCriteria =
    Map[__string, zio.aws.macie2.model.BucketCriteriaAdditionalProperties]
  type Cells = List[zio.aws.macie2.model.Cell]
  type Criterion =
    Map[__string, zio.aws.macie2.model.CriterionAdditionalProperties]
  type CustomDetections = List[zio.aws.macie2.model.CustomDetection]
  type DefaultDetections = List[zio.aws.macie2.model.DefaultDetection]
  type KeyValuePairList = List[zio.aws.macie2.model.KeyValuePair]
  type Pages = List[zio.aws.macie2.model.Page]
  type Ranges = List[zio.aws.macie2.model.Range]
  type Records = List[zio.aws.macie2.model.Record]
  type SensitiveData = List[zio.aws.macie2.model.SensitiveDataItem]
  type SensitiveDataOccurrences =
    Map[__string, Iterable[zio.aws.macie2.model.DetectedDataDetails]]
  type SeverityLevelList = List[zio.aws.macie2.model.SeverityLevel]
  type TagMap = Map[__string, __string]
  type __listOfAdminAccount = List[zio.aws.macie2.model.AdminAccount]
  type __listOfAllowListSummary = List[zio.aws.macie2.model.AllowListSummary]
  type __listOfBatchGetCustomDataIdentifierSummary =
    List[zio.aws.macie2.model.BatchGetCustomDataIdentifierSummary]
  type __listOfBucketMetadata = List[zio.aws.macie2.model.BucketMetadata]
  type __listOfCriteriaForJob = List[zio.aws.macie2.model.CriteriaForJob]
  type __listOfCustomDataIdentifierSummary =
    List[zio.aws.macie2.model.CustomDataIdentifierSummary]
  type __listOfDetectedDataDetails =
    List[zio.aws.macie2.model.DetectedDataDetails]
  type __listOfFinding = List[zio.aws.macie2.model.Finding]
  type __listOfFindingType = List[zio.aws.macie2.model.FindingType]
  type __listOfFindingsFilterListItem =
    List[zio.aws.macie2.model.FindingsFilterListItem]
  type __listOfGroupCount = List[zio.aws.macie2.model.GroupCount]
  type __listOfInvitation = List[zio.aws.macie2.model.Invitation]
  type __listOfJobScopeTerm = List[zio.aws.macie2.model.JobScopeTerm]
  type __listOfJobSummary = List[zio.aws.macie2.model.JobSummary]
  type __listOfKeyValuePair = List[zio.aws.macie2.model.KeyValuePair]
  type __listOfListJobsFilterTerm =
    List[zio.aws.macie2.model.ListJobsFilterTerm]
  type __listOfManagedDataIdentifierSummary =
    List[zio.aws.macie2.model.ManagedDataIdentifierSummary]
  type __listOfMatchingResource = List[zio.aws.macie2.model.MatchingResource]
  type __listOfMember = List[zio.aws.macie2.model.Member]
  type __listOfS3BucketDefinitionForJob =
    List[zio.aws.macie2.model.S3BucketDefinitionForJob]
  type __listOfSearchResourcesCriteria =
    List[zio.aws.macie2.model.SearchResourcesCriteria]
  type __listOfSearchResourcesTagCriterionPair =
    List[zio.aws.macie2.model.SearchResourcesTagCriterionPair]
  type __listOfTagCriterionPairForJob =
    List[zio.aws.macie2.model.TagCriterionPairForJob]
  type __listOfTagValuePair = List[zio.aws.macie2.model.TagValuePair]
  type __listOfUnavailabilityReasonCode =
    List[zio.aws.macie2.model.UnavailabilityReasonCode]
  type __listOfUnprocessedAccount =
    List[zio.aws.macie2.model.UnprocessedAccount]
  type __listOfUsageByAccount = List[zio.aws.macie2.model.UsageByAccount]
  type __listOfUsageRecord = List[zio.aws.macie2.model.UsageRecord]
  type __listOfUsageStatisticsFilter =
    List[zio.aws.macie2.model.UsageStatisticsFilter]
  type __listOfUsageTotal = List[zio.aws.macie2.model.UsageTotal]
  type __listOf__string = List[__string]
}

==> zio-aws-macie2_3-5.17.116.1-sources.jar: zio/aws/macie2/model/package.scala <==
package zio.aws.macie2
import zio.prelude.Subtype
import zio.aws.macie2.model.primitives.__string
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.macie2.model.primitives.MaxResults.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.macie2.model.primitives.__boolean.Type
    object __double extends Subtype[Double]
    type __double = zio.aws.macie2.model.primitives.__double.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.macie2.model.primitives.__integer.Type
    object __long extends Subtype[Long]
    type __long = zio.aws.macie2.model.primitives.__long.Type
    object __string extends Subtype[String]
    type __string = zio.aws.macie2.model.primitives.__string.Type
    object __timestampIso8601 extends Subtype[Instant]
    type __timestampIso8601 =
      zio.aws.macie2.model.primitives.__timestampIso8601.Type
  }
  type BucketCriteria =
    Map[__string, zio.aws.macie2.model.BucketCriteriaAdditionalProperties]
  type Cells = List[zio.aws.macie2.model.Cell]
  type Criterion =
    Map[__string, zio.aws.macie2.model.CriterionAdditionalProperties]
  type CustomDetections = List[zio.aws.macie2.model.CustomDetection]
  type DefaultDetections = List[zio.aws.macie2.model.DefaultDetection]
  type KeyValuePairList = List[zio.aws.macie2.model.KeyValuePair]
  type Pages = List[zio.aws.macie2.model.Page]
  type Ranges = List[zio.aws.macie2.model.Range]
  type Records = List[zio.aws.macie2.model.Record]
  type SensitiveData = List[zio.aws.macie2.model.SensitiveDataItem]
  type SeverityLevelList = List[zio.aws.macie2.model.SeverityLevel]
  type TagMap = Map[__string, __string]
  type __listOfAdminAccount = List[zio.aws.macie2.model.AdminAccount]
  type __listOfBatchGetCustomDataIdentifierSummary =
    List[zio.aws.macie2.model.BatchGetCustomDataIdentifierSummary]
  type __listOfBucketMetadata = List[zio.aws.macie2.model.BucketMetadata]
  type __listOfCriteriaForJob = List[zio.aws.macie2.model.CriteriaForJob]
  type __listOfCustomDataIdentifierSummary =
    List[zio.aws.macie2.model.CustomDataIdentifierSummary]
  type __listOfFinding = List[zio.aws.macie2.model.Finding]
  type __listOfFindingType = List[zio.aws.macie2.model.FindingType]
  type __listOfFindingsFilterListItem =
    List[zio.aws.macie2.model.FindingsFilterListItem]
  type __listOfGroupCount = List[zio.aws.macie2.model.GroupCount]
  type __listOfInvitation = List[zio.aws.macie2.model.Invitation]
  type __listOfJobScopeTerm = List[zio.aws.macie2.model.JobScopeTerm]
  type __listOfJobSummary = List[zio.aws.macie2.model.JobSummary]
  type __listOfKeyValuePair = List[zio.aws.macie2.model.KeyValuePair]
  type __listOfListJobsFilterTerm =
    List[zio.aws.macie2.model.ListJobsFilterTerm]
  type __listOfManagedDataIdentifierSummary =
    List[zio.aws.macie2.model.ManagedDataIdentifierSummary]
  type __listOfMatchingResource = List[zio.aws.macie2.model.MatchingResource]
  type __listOfMember = List[zio.aws.macie2.model.Member]
  type __listOfS3BucketDefinitionForJob =
    List[zio.aws.macie2.model.S3BucketDefinitionForJob]
  type __listOfSearchResourcesCriteria =
    List[zio.aws.macie2.model.SearchResourcesCriteria]
  type __listOfSearchResourcesTagCriterionPair =
    List[zio.aws.macie2.model.SearchResourcesTagCriterionPair]
  type __listOfTagCriterionPairForJob =
    List[zio.aws.macie2.model.TagCriterionPairForJob]
  type __listOfTagValuePair = List[zio.aws.macie2.model.TagValuePair]
  type __listOfUnprocessedAccount =
    List[zio.aws.macie2.model.UnprocessedAccount]
  type __listOfUsageByAccount = List[zio.aws.macie2.model.UsageByAccount]
  type __listOfUsageRecord = List[zio.aws.macie2.model.UsageRecord]
  type __listOfUsageStatisticsFilter =
    List[zio.aws.macie2.model.UsageStatisticsFilter]
  type __listOfUsageTotal = List[zio.aws.macie2.model.UsageTotal]
  type __listOf__string = List[__string]
}
